function [ theta, r ] = Cart2polD( D )
%Cart2pol Converts the p dimensional cartesian data D into polar co-ordinates
%   For more info Kendall, M. G. (1961). A Course in the Geometry of n Dimensions (no. 8 of Griffins Statistical
% Monographs and Courses). New York: Hafner.

[n, p]=size(D);
r=sqrt(sum(D.^2,2)); %get the hypotenuse
theta=zeros(n,p-1);
rct=zeros(n,p); %r cos theta values stored for faster implementation
rct(:,1)=r;
for i=1:p-1;
    theta(:,i)=real(asind(D(:,p-i+1)./(rct(:,i))));
    rct(:,i+1)=real(real(rct(:,i)).*real(cosd(theta(:,i))));        
end

end

    