function [sortedMahalanobis, chiSquareQuantile, rSquaredFitting]=chiSquaredQQplot(data,distance)
%chiSquaredQQplot calculates mutlivariate normality by chi squared quantile-quantile plotting

% data is a matix of the input data to be tested as n pixels by d mass channels
% distance is either specified as 'Euclidean' or 'Cosine' defualt is Euclidean distance

%% If using cosine distance convert to polar co-ordiantes first
if strcmp(distance,'Cosine') 
    [theta, ~]=Cart2pol(data);
    theta(isnan(theta))=0;
    data=theta;
end


%% reduce by PCA and remove zero components
[~, C]=princomp(data);
findZeroComponents=sum(C,1);
C=C(:,findZeroComponents~=0); %remove fully zeros columns of C
zeroComponentCheck=sum(C,2);
C=C(zeroComponentCheck~=0,:);
n=sum(zeroComponentCheck~=0);
p=sum(findZeroComponents~=0); %get the new size of the data

%% calculate Mahalanobis distance
variancesPCAspace=zeros(1,p);
for i=1:p;
    variancesPCAspace(i)=var(C(:,i));
end
variancesPCAspace=variancesPCAspace(variancesPCAspace~=0);
standardDeviatrionPCAspace=sqrt(variancesPCAspace);
meanCentering=mean(C,1);
meanCentred=abs(C-repmat(meanCentering,n,1));
meanCenteredVarianceScaled=meanCentred./repmat(standardDeviatrionPCAspace,n,1);
mahalanobisDistacne=sum((meanCenteredVarianceScaled),2) .^2;


sortedMahalanobis = sort(mahalanobisDistacne);   %sorted squared Mahalanobis distances
r = tiedrank(sortedMahalanobis);  %ranks of the squared Mahalanobis distances
if strcmp(distance,'Cosine') %use one less degree of freedom for polar data ( one less dimension )
    chiSquareQuantile=chi2inv((r-0.5)./n,(p+1));  %chi-square quantiles
else
    chiSquareQuantile=chi2inv((r-0.5)./n,(p));  %chi-square quantiles
end
rSquaredFitting = corr(sortedMahalanobis, chiSquareQuantile);

end

