function [ syntheticData ] = generateSyntheticDataFromCholcovCosine( referenceData, numberOfPixels, T)
%generateSyntheticDataFromCholcovCosine Generates synthetic dataset by statistical modelling of the input reference data with Cholesky factor already determined

%   referenceData is an input matrix of the reference data to be modelled
%   numberOfPixels is a vector of number of pixels to be generated for each of the regions
%   T is the Cholesky factor provided by generateSyntheticDataCosine

%% Convert data to polar co-ordinates and get means and varainces
    [polarData, polarHypotenuse] = Cart2polD(referenceData);    %convert real data to polar co-ordiantes
    polarData(isnan(polarData)) = 0; %remove NaNs created in polar conversion
    polarMean = mean(polarData);    %determine mean
    hypotenuseMean = mean(polarHypotenuse);    %determine the hypotenuse mean
    hypotenuseStandardDeviation = std(polarHypotenuse);      %determine the hypotenuse standard deviation

%% Setup synthetic data from real data
    polarSynthetic = randn(numberOfPixels, size(T,1)) * T + repmat(polarMean, numberOfPixels, 1); %set up multivariate normal polar data with mean and covariance of the real data
    hypotenuseSynthetic = abs(randn(numberOfPixels,1).*hypotenuseStandardDeviation + hypotenuseMean);    %set up normally distribiuted hypotenuse with mean and standard deviatin of the real data
    syntheticData = Pol2CartD(hypotenuseSynthetic, polarSynthetic); %convert the data back to cartesian co-ordinates
    syntheticData = abs(syntheticData);
end

